@@ -53,7 +53,7 @@ class ApiClient:
             if response.status_code == 401:
                 raise GarminConnectAuthenticationError("Authentication error") from err
             if response.status_code == 403:
-                raise GarminConnectConnectionError("Forbidden url") from err
+                raise GarminConnectConnectionError(f"Forbidden get url: {url}") from err
             if response.status_code == 500:
                 raise GarminConnectConnectionError("Server error") from err
             if response.status_code == 404:
@@ -86,7 +86,7 @@ class ApiClient:
             if response.status_code == 401:
                 raise GarminConnectAuthenticationError("Authentication error") from err
             if response.status_code == 403:
-                raise GarminConnectConnectionError("Forbidden url: %s", url) from err
+                raise GarminConnectConnectionError(f"Forbidden post url: {url}") from err
             if response.status_code == 500:
                 raise GarminConnectConnectionError("Server error") from err
             if response.status_code == 404:
@@ -442,6 +442,15 @@ class Garmin:
 
         return self.modern_rest_client.get(url, params=params).json()
 
+    def get_last_activity(self):
+        """Return last activity."""
+
+        activities = self.get_activities(0,1)
+        if activities:
+            return activities[-1]
+
+        return None
+
     class ActivityDownloadFormat(Enum):
         """Activitie variables."""
 
@@ -543,29 +552,10 @@ class Garmin:
 class GarminConnectConnectionError(Exception):
     """Raised when communication ended in error."""
 
-    def __init__(self, message):
-        self.message = message
-        super().__init__(self.message)
-
-    def __str__(self):
-        return self.message
 
 class GarminConnectTooManyRequestsError(Exception):
     """Raised when rate limit is exceeded."""
 
-    def __init__(self, message):
-        self.message = message
-        super().__init__(self.message)
-
-    def __str__(self):
-        return self.message
 
 class GarminConnectAuthenticationError(Exception):
     """Raised when authentication is failed."""
-
-    def __init__(self, message):
-        self.message = message
-        super().__init__(self.message)
-
-    def __str__(self):
-        return self.message
